#
# spec file for package python-shodan
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?license: %global license %doc}
Name:           python-shodan
Version:        1.31.0
Release:        4.1
Summary:        Python library and command-line utility for Shodan
License:        MIT
URL:            https://github.com/achillean/shodan-python/
Source:         https://files.pythonhosted.org/packages/source/s/shodan/shodan-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove-click-plugins.patch -- remove dependency to unmaintained click-plugins
Patch0:         https://github.com/achillean/shodan-python/pull/236.patch#/remove-click-plugins.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-XlsxWriter
Requires:       python-click
Requires:       python-colorama
Requires:       python-requests >= 2.2.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-curses
Suggests:       %{name}-doc
BuildArch:      noarch
%python_subpackages

%package -n %{name}-doc
Summary:        Documentation files for %{name}
Group:          Documentation/HTML
Provides:       %{python_module shodan-doc = %{version}}

%description
Shodan is a search engine for Internet-connected devices. Google lets you search for websites, Shodan lets you search for devices. This library provides developers easy access to all of the data stored in Shodan in order to automate tasks and integrate into existing tools.

%description -n %{name}-doc
HTML documentation on the API and examples for %{name}.

%prep
%autosetup -n shodan-%{version} -p1
sed -i '1s/^#!.*//' shodan/cli/worldmap.py

%build
%pyproject_wheel
pushd docs
%make_build html
rm -r _build/html/.buildinfo _build/html/_sources/
%make_build man
popd

%install
%pyproject_install
install -Dm 644 docs/_build/man/shodan-python.1 %{buildroot}%{_mandir}/man1/shodan.1
%python_clone -a %{buildroot}%{_bindir}/shodan
%python_clone -a %{buildroot}%{_mandir}/man1/shodan.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Tests need network access, skip them:
# https://developer.shodan.io/api/requirements
# SHODAN-API-KEY file required by tests

%post
%python_install_alternative shodan shodan.1

%postun
%python_uninstall_alternative shodan shodan.1

%files %{python_files}
%doc AUTHORS README.rst
%license LICENSE
%python_alternative %{_bindir}/shodan
%{python_sitelib}/shodan
%{python_sitelib}/shodan-%{version}.dist-info
%python_alternative %{_mandir}/man1/shodan.1%{ext_man}

%files -n %{name}-doc
%doc docs/_build/html

%changelog
* Mon Jun 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyroject macros.
- No more greedy globs in %%files.
* Tue May 13 2025 Sebastian Wagner <sebix@sebix.at>
- add patch remove-click-plugins.patch to remove the dependency on unmaintained click-plugins
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.31.0:
  * no upstream changelog available
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.28.0
  * Add the ability to whitelist a specific vulnerability in Shodan Monitor instead of whitelisting the while IP:port
  * Show scan ID when scanning without showing results (credit to @seadog007)
  * Handle bad gateway errors (credit to @yaron-cider)
* Fri Feb 25 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- - update to version 1.27.0:
  - New command: ``shodan alert export`` to save the current network monitoring configuration
  - New command: ``shodan alert import`` to restore a previous network monitoring configuration
  - Automatically rate limit API requests to 1 request per second (credit to @malvidin)
- update to version 1.26.1:
  - Fix a unicode issue that caused the streams to get truncated and error out due to invalid JSON
- update to version 1.26.0:
  - Add the ability to create custom data streams in the Shodan() class as well as the CLI (``shodan stream --custom-filters <query>``)
- update to version 1.25.0:
  - Add new CLI command: shodan alert download
* Wed Jan 19 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- - update to version 1.25.0:
  - Add new CLI command: shodan alert download
- update to version 1.24.0:
  - Add new CLI command: shodan alert stats
- update to version 1.23.0:
  - Add new CLI command: shodan alert domain
- update to version 1.22.1:
  - Fix bug when converting data file to CSV using Python3
- update to version 1.22.0:
  - Add support for new vulnerability streaming endpoints
- update to version 1.21.3:
  - Fix geo.json file converter
- update to version 1.21.2:
  - Add support for paging through the domain information
- update to version 1.21.1:
  - Add ``history`` and ``type`` parameters to ``Shodan.dns.domain_info()`` method and CLI command
- update to version 1.21.0:
  - New API methods ``api.search_facets()`` and ``api.search_filters()`` to get a list of available facets and filters.
- update to version 1.20.0:
  - New option "-S" for **shodan domain** to save results from the lookup
  - New option "-D" for **shodan domain** to lookup open ports for IPs in the results
- update to version 1.19.0:
  - New method to edit the list of IPs for an existing network alert
- update to version 1.18.0:
  - Add library methods for the new Notifications API
- update to version 1.17.0:
  - Fix bug that caused unicode error when printing domain information (#106)
  - Add flag to let users get their IPv6 address **shodan myip -6**(#35)
- update to version 1.16.0:
  - Ability to specify list of fields to include when converting to CSV/ Excel (#107)
  - Filter the Shodan Firehose based on tags in the banner
- update to version 1.15.0:
  - New option "--skip" for download command to help users resume a download
- update to version 1.14.0:
  - New command **shodan version** (#104).
  - Only change api_key file permissions if needed (#103)
- update to version 1.13.0:
  - New command **shodan domain** to lookup a domain in Shodan's DNS database
  - Override environment configured settings if explicit proxy settings are supplied (@cudeso)
- update to version 1.12.1:
  - Fix Excel file conversion that resulted in empty .xlsx files
- update to version 1.12.0:
  - Add new methods to ignore/ unignore trigger notifications
- update to version 1.11.1:
  - Allow a single network alert to monitor multiple IP ranges (#93)
- update to version 1.11.0:
  - New command **shodan scan list** to list recently launched scans
  - New command **shodan alert triggers** to list the available notification triggers
  - New command **shodan alert enable** to enable a notification trigger
  - New command **shodan alert disable** to disable a notification trigger
  - New command **shodan alert info** to show details of a specific alert
  - Include timestamp, vulns and tags in CSV converter (#85)
  - Fixed bug that caused an exception when parsing uncompressed data files in Python3
  - Code quality improvements
  - Thank you for contributions from @wagner-certat, @cclauss, @opt9, @voldmar and Antoine Neuenschwander
- update to version 1.10.4:
  - Fix a bug when showing old banner records that don't have the "transport" property
  - Code quality improvements (bare excepts)
- update to version 1.10.3:
  - Change bare 'except:' statements to 'except Exception:' or more specific ones
  - remove unused imports
  - Convert line endings of `shodan/client.py` and `tests/test_shodan.py` to unix
  - List file types in **shodan convert** (#80)
- update to version 1.10.2:
  - Fix **shodan stats** formatting exception when faceting on **port**
- update to version 1.10.1:
  - Support PUT requests in the API request helper method
- update to version 1.10.0:
  - New command **shodan org**: manage enterprise access to Shodan for your team
  - Improved unicode handling (#78)
  - Remove deprecated API wrapper for shodanhq.com/api
- update to version 1.9.1:
  - The CHANGELOG is now part of the packages.
  - Improved unicode handling in Python2 (#78)
  - Add `tsv` output format for **shodan host** (#65)
  - Show user-friendly error messages when running **shodan radar** without permission or in a window that's too small (#74)
  - Improved exception handling to improve debugging **shodan init** (#77)
- update to version 1.9.0:
  - New optional parameter `proxies` for all interfaces to specify a proxy array for the requests library (#72)
- update to version 1.8.1:
  - Fixed bug that prevented **shodan scan submit** from finishing (#70)
- update to version 1.8.0:
  - Shodan CLI now installs properly on Windows (#66)
  - Improved output of "shodan host" (#64, #67)
  - Fixed bug that prevented an open port from being shown in "shodan host" (#63)
  - No longer show an empty page if "shodan search" didn't return results (#62)
  - Updated docs to make them Python3 compatible
- update to version 1.7.7:
  - Added "shodan data download" command to help download bulk data files
- update to version 1.7.6:
  - Add basic support for the Bulk Data API
- update to version 1.7.5:
  * Handle Cloudflare timeouts
- update to version 1.7.4:
  * Added "shodan radar" command
- update to version 1.7.3:
  * Fixed the bug #47 which was caused by the CLI using a timeout value of "0" which resulted in the "requests" library failing to connect
- update to version 1.7.2:
  * stream: automatically decode to unicode, fixes streaming on python3 (#45)
  * Include docs in packages (#46)
  * stream: handle timeout=None, None (default) can't be compared with integers (#44)
- update to version 1.7.1:
  * Python3 fixes for outputting images (#42)
  * Add the ability to save results from host lookups via the CLI (#43)
- update to version 1.7.0:
  * Added "images" convert output format to let users extract images from Shodan data files (#42)
* Fri Jan  7 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.26.0:
  - Add the ability to create custom data streams in the Shodan() class as well as the CLI (shodan stream --custom-filters <query>)
* Tue Jan 26 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.25.0:
  - Add new CLI command: shodan alert download [--alert-id=] <filename>
* Sun Nov  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.24.0:
  * use default config dir `~/.config/shodan`, but support existing installations
  * Fix bug that caused extra newlines when converting `.json.gz` data file to CSV on Windows
  * Fix linting error
* Sat Sep 12 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.23.1:
  * Fixed linting errors
  * Import ABC from collections.abc for Python 3.10 compatibility (#130).
  * Fix invalid escape sequence error, improves ``shodan radar`` output on Python3 (#131).
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Apr  7 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.23.0:
  - Add new CLI command: shodan alert domain
* Fri Mar 27 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.22.1:
  - vulns: Fix bug when converting data file to CSV using Python3
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 1.22.0
  * New Streaming API method: /shodan/vulns/{vulns} to subscribe to IPs
    that are vulnerable to an issue
* Sat Feb  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.21.3:
  - Fix geo.json file converter
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.21.2:
  - Add support for paging through the domain information
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.21.1:
  - Add ``history`` and ``type`` parameters to ``Shodan.dns.domain_info()`` method and CLI command
* Sun Dec 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.21.0:
  - New API methods ``api.search_facets()`` and ``api.search_filters()`` to get a list of available facets and filters.
* Tue Nov 26 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.20.0:
  - New option "-S" for **shodan domain** to save results from the lookup
  - New option "-D" for **shodan domain** to lookup open ports for IPs in the results
* Tue Oct  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.19.0
  * Ability to specify list of fields to include when converting to CSV/ Excel
  * Filter the Shodan Firehose based on tags in the banner
  * Fix bug that caused unicode error when printing domain information
  * Add flag to let users get their IPv6 address shodan myip -6
  * Add library methods for the new Notifications API
  * New method to edit the list of IPs for an existing network alert
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.15.0:
  * New option --skip for the shodan download command to skip results
* Sun Jul 21 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.14.0:
  - New command **shodan version** (#104).
  - Only change api_key file permissions if needed (#103)
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.13.0:
  * New command **shodan domain** to lookup a domain in Shodan's DNS database
  * Override environment configured settings if explicit proxy settings are supplied (@cudeso)
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 1.12.1
  * Fix Excel file conversion that resulted in empty .xlsx files
* Sun Apr  7 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.12.0:
  * Add new methods to ignore/ unignore trigger notifications
* Sat Mar 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.11.1:
  * Allow a single network alert to monitor multiple IP ranges (#93)
- update to version 1.11.0:
  * New command **shodan scan list** to list recently launched scans
  * New command **shodan alert triggers** to list the available notification triggers
  * New command **shodan alert enable** to enable a notification trigger
  * New command **shodan alert disable** to disable a notification trigger
  * New command **shodan alert info** to show details of a specific alert
  * Include timestamp, vulns and tags in CSV converter (#85)
  * Fixed bug that caused an exception when parsing uncompressed data files in Python3
  * Code quality improvements
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Oct 14 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.4:
  * Fix a bug when showing old banner records that don't have the "transport" property
* Sat Sep 22 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.3:
  * Change bare 'except:' statements to 'except Exception:' or more specific ones
  * remove unused imports
  * Convert line endings of `shodan/client.py` and `tests/test_shodan.py` to unix
  * List file types in **shodan convert** (#80)
* Mon Sep 17 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.2
  * Fix **shodan stats** formatting exception when faceting on **port**
- update to version 1.10.1:
  * Support PUT requests in the API request helper method
* Sun Sep  2 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.0:
  * New command **shodan org**: manage enterprise access to Shodan for your team
  * Improved unicode handling (#78)
  * Remove deprecated API wrapper for shodanhq.com/api
* Sun Aug 26 2018 sebix+novell.com@sebix.at
- update to version 1.9.1:
  * The CHANGELOG is now part of the packages.
  * Improved unicode handling in Python2 (#78)
  * Add `tsv` output format for **shodan host** (#65)
  * Show user-friendly error messages when running **shodan radar** without permission or in a window that's too small (#74)
  * Improved exception handling to improve debugging **shodan init** (#77)
* Wed Aug  1 2018 sebix+novell.com@sebix.at
- update to version 1.9.0:
  * New optional parameter proxies for all interfaces to specify a proxy array for the requests library (#72)
- update to version 1.8.1:
  * Fixed bug that prevented shodan scan submit from finishing (#70)
* Thu May 31 2018 sebix+novell.com@sebix.at
- update to version 1.8.0:
  * Shodan CLI now installs properly on Windows (#66)
  * Improved output of "shodan host" (#64, #67)
  * Fixed bug that prevented an open port from being shown in "shodan host" (#63)
  * No longer show an empty page if "shodan search" didn't return results (#62)
  * Updated docs to make them Python3 compatible
* Sun Dec 10 2017 sebix+novell.com@sebix.at
- update to version 1.7.7
  * Added "shodan data download" command to help download bulk data files
* Tue Dec  5 2017 sebix+novell.com@sebix.at
- update to version 1.7.6:
  * addes "shodan radar" command
* Mon Sep  4 2017 sebix+novell.com@sebix.at
- upgrade to version 1.7.5
* Thu Aug  3 2017 sebix+novell.com@sebix.at
- fix build for leap
* Wed Jul 19 2017 sebix+novell.com@sebix.at
- initial version
